@@ -1,6 +1,6 @@
 from calendar import timegm
 
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from .. import exceptions
 from ..settings import jwt_settings
